# lifted from lilypond

AC_DEFUN(AC_GUILE_CONFIG, [
    ## First, let's just see if we can find Guile at all.
    AC_MSG_CHECKING("for guile-config")
    for GUILE_CONFIG in guile-config $target-guile-config $build-guile-config; do
        AC_MSG_RESULT("$GUILE_CONFIG")
        if ! $GUILE_CONFIG --version > /dev/null 2>&1 ; then
            AC_MSG_WARN("cannot execute $GUILE_CONFIG")
            AC_MSG_CHECKING("if we are cross compiling")
            GUILE_CONFIG=error
        else
            break
        fi
    done
    if test "$GUILE_CONFIG" = "error"; then
        AC_MSG_ERROR("cannot find guile-config; is Guile installed?")
        exit 1
    fi
    AC_SUBST(GUILE_CONFIG)
])

AC_DEFUN(AC_GUILE_VERSION, [
    AC_MSG_CHECKING("Guile version")
    need_guile_version="1.4"
    need_guile_version_numeric=100400
    guile_version=`$GUILE_CONFIG --version 2>&1 | awk '{print $NF}'`
    guile_version_numeric=`echo $guile_version | awk -F. '
{if ([$]3) {last = [$]3}
else {last =0}}
{printf "%s%s%s\n",[$]1*100, [$]2*10,last}'`
    AC_MSG_RESULT("$guile_version")
    if test $guile_version_numeric -lt $need_guile_version_numeric
    then
        AC_MSG_ERROR("Guile version "$need_guile_version" or newer is needed")
    fi
])

AC_DEFUN(AC_GUILE, [
    AC_PATH_PROG(GUILE, guile, error)
    AC_SUBST(GUILE)
])

AC_DEFUN(AC_GUILE_CFLAGS, [
    GUILE_CFLAGS="`$GUILE_CONFIG compile`"
    AC_SUBST(GUILE_CFLAGS)
])

AC_DEFUN(AC_GUILE_LDFLAGS, [
    GUILE_LDFLAGS="`$GUILE_CONFIG link`"
    AC_SUBST(GUILE_LDFLAGS)
])

AC_DEFUN(AC_GUILE_PKGDATADIR, [
    AC_MSG_CHECKING(for Guile module directory)
    GUILE_PKGDATADIR="`$GUILE_CONFIG info pkgdatadir`"
    AC_MSG_RESULT("$GUILE_PKGDATADIR")
    AC_SUBST(GUILE_PKGDATADIR)
])

AC_DEFUN(AC_GUILE_SITEDIR, [
    AC_MSG_CHECKING(for Guile site directory)
    GUILE_SITEDIR="`$GUILE -c \"(display (%site-dir))\"`"
    AC_MSG_RESULT("$GUILE_SITEDIR")
    AC_SUBST(GUILE_SITEDIR)
])
